@@ -1,11 +1,11 @@
 """tests for the McapReader implementations."""
 import os
 from pathlib import Path
-
 import pytest
+from typing import IO, Tuple, Type
 
-from mcap.mcap0.reader import make_reader, SeekingReader, NonSeekingReader, McapReader
-from mcap.mcap0.records import Schema, Channel, Message
+from mcap.reader import make_reader, SeekingReader, NonSeekingReader, McapReader
+from mcap.records import Schema, Channel, Message
 
 DEMO_MCAP = (
     Path(__file__).parent.parent.parent.parent / "testdata" / "mcap" / "demo.mcap"
@@ -29,7 +29,7 @@ def test_make_seeking():
         assert isinstance(reader, SeekingReader)
 
 
-def test_make_not_seeking(pipe):
+def test_make_not_seeking(pipe: Tuple[IO[bytes], IO[bytes]]):
     """test that non-seekable streams get read with the non-seeking reader."""
     r, _ = pipe
     reader: McapReader = make_reader(r)
@@ -37,7 +37,7 @@ def test_make_not_seeking(pipe):
 
 
 @pytest.mark.parametrize("reader_cls", [SeekingReader, NonSeekingReader])
-def test_all_messages(reader_cls):
+def test_all_messages(reader_cls: Type[McapReader]):
     """test that we can find all messages correctly with all reader implementations."""
     with open(DEMO_MCAP, "rb") as f:
         reader: McapReader = reader_cls(f)
@@ -52,7 +52,7 @@ def test_all_messages(reader_cls):
 
 
 @pytest.mark.parametrize("reader_cls", [SeekingReader, NonSeekingReader])
-def test_time_range(reader_cls):
+def test_time_range(reader_cls: Type[McapReader]):
     """test that we can filter by time range with all reader implementations."""
     with open(DEMO_MCAP, "rb") as f:
         reader: McapReader = reader_cls(f)
@@ -73,7 +73,7 @@ def test_time_range(reader_cls):
 
 
 @pytest.mark.parametrize("reader_cls", [SeekingReader, NonSeekingReader])
-def test_only_diagnostics(reader_cls):
+def test_only_diagnostics(reader_cls: Type[McapReader]):
     """test that we can filter by topic with all reader implementations."""
     with open(DEMO_MCAP, "rb") as f:
         reader: McapReader = reader_cls(f)
