@@ -8,16 +8,16 @@ import zlib
 import lz4.frame
 import pytest
 
-from mcap.mcap0.writer import CompressionType, Writer
-from mcap.mcap0.records import Chunk, ChunkIndex, Statistics
-from mcap.mcap0.stream_reader import StreamReader
+from mcap.writer import CompressionType, Writer
+from mcap.records import Chunk, ChunkIndex, Statistics
+from mcap.stream_reader import StreamReader
 
 
 @contextlib.contextmanager
 def generate_sample_data(compression: CompressionType):
     file = TemporaryFile("w+b")
     writer = Writer(file, compression=compression)
-    writer.start(profile="x-json", library="test")
+    writer.start(library="test")
     schema_id = writer.register_schema(
         name="sample",
         encoding="jsonschema",
@@ -75,7 +75,7 @@ def test_lz4_chunks():
 
 
 @pytest.mark.parametrize(
-    "compression_type,length", [(CompressionType.ZSTD, 747), (CompressionType.LZ4, 785)]
+    "compression_type,length", [(CompressionType.ZSTD, 741), (CompressionType.LZ4, 779)]
 )
 def test_decode_read(compression_type, length):
     """tests that chunk compression is happening when writing."""
@@ -87,7 +87,7 @@ def test_decode_read(compression_type, length):
 def test_out_of_order_messages():
     io = BytesIO()
     writer = Writer(io, compression=CompressionType.ZSTD)
-    writer.start(profile="x-json", library="test")
+    writer.start(library="test")
     schema_id = writer.register_schema("schema", "unknown", b"")
     channel_id = writer.register_channel("topic", "enc", schema_id)
     writer.add_message(channel_id, 100, b"a", 100)
